<?php

namespace MaagIT\MaagSupermailer\Controller;


/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Urs Maag <info@maagit.ch>, maagIT
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package supermailer
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class SupermailerController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {
	
	// ============================================================================================================================================================= //
	//                                                                                                                                                               //
	// variables and constants                                                                                                                                       //
	//                                                                                                                                                               //
	// ============================================================================================================================================================= //
	
	/**
	 * @var	\MaagIT\MaagSupermailer\Domain\Repository\SupermailerRepository
	 * @inject
	 */
	 protected $supermailerRepository;


	// ============================================================================================================================================================= //
	//                                                                                                                                                               //
	// public methods                                                                                                                                                //
	//                                                                                                                                                               //
	// ============================================================================================================================================================= //

	/**
     * action subscribe
     *
	 * @param  \MaagIT\MaagSupermailer\Domain\Model\Supermailer $supermailer
	 * @return void
     */
	public function subscribeAction(\MaagIT\MaagSupermailer\Domain\Model\Supermailer $supermailer = NULL) {
		// Validation
		if ($supermailer != NULL) {
    		$validator = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('MaagIT\\MaagSupermailer\\Validator\\SubscribeValidator');
    		$isValid = $validator->validate($supermailer);
    		if (!$isValid)	{
    			$supermailer->setError($validator->getMessage());
    		}
		}
		
		// Send Mail
		if ($supermailer != NULL && $isValid)	{
			if (\TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('MaagIT\\MaagSupermailer\\Mailer\\Mailer')->sendMail($supermailer, \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('email.subject.subscribe', 'MaagSupermailer')))	{
				$url = $this->uriBuilder->setRequest($this->request)->setTargetPageUid($this->settings['confirmation']['subscribe'])->buildFrontendUri();
			}	else	{
				$url = $this->uriBuilder->setRequest($this->request)->setTargetPageUid($this->settings['confirmation']['error'])->buildFrontendUri();
			}
			$this->redirectToUri($url);
		}

		// show view
		$this->initTemplateFile($this->settings['path']['subscribe']);
		$this->view->assign('supermailer', $supermailer);
	}
	
	/**
     * action unsubscribe
     *
     * @param  \MaagIT\MaagSupermailer\Domain\Model\Supermailer $supermailer
	 * @return void
     */
	public function unsubscribeAction(\MaagIT\MaagSupermailer\Domain\Model\Supermailer $supermailer = NULL) {
		// Validation
		if ($supermailer != NULL) {
    		$validator = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('MaagIT\\MaagSupermailer\\Validator\\UnsubscribeValidator');
    		$isValid = $validator->validate($supermailer);
    		if (!$isValid)	{
    			$supermailer->setError($validator->getMessage());
    		}
		}
		
		// Send Mail
		if ($supermailer != NULL && $isValid)	{
			if (\TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('MaagIT\\MaagSupermailer\\Mailer\\Mailer')->sendMail($supermailer, \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('email.subject.unsubscribe', 'MaagSupermailer')))	{
				$url = $this->uriBuilder->setRequest($this->request)->setTargetPageUid($this->settings['confirmation']['unsubscribe'])->buildFrontendUri();
			}	else	{
				$url = $this->uriBuilder->setRequest($this->request)->setTargetPageUid($this->settings['confirmation']['error'])->buildFrontendUri();
			}
			$this->redirectToUri($url);
		}
		
		// show view
		$this->initTemplateFile($this->settings['path']['unsubscribe']);
		$this->view->assign('supermailer', $supermailer);
	}
	

	// ============================================================================================================================================================= //
	//                                                                                                                                                               //
	// protected methods                                                                                                                                             //
	//                                                                                                                                                               //
	// ============================================================================================================================================================= //




	// ============================================================================================================================================================= //
	//                                                                                                                                                               //
	// private methods                                                                                                                                               //
	//                                                                                                                                                               //
	// ============================================================================================================================================================= //	

	/**
     * set template path, if is defined over settings
     *
     * @param string	$file
	 * @return void
     */
	private function initTemplateFile($file)	{
		if ($file != '')	{
			$this->view->setTemplatePathAndFilename($file);
		}
	}

}
?>